Public API Header
=================

The core API is defined in `public_api.h
<https://github.com/hpyproject/hpy/blob/master/hpy/tools/autogen/public_api.h>`_:

.. literalinclude:: ../../hpy/tools/autogen/public_api.h
    :language: c
    :linenos:
